<?php // phpcs:ignore WordPress.Files.FileName.NotHyphenatedLowercase
/**
 * Block patterns service.
 *
 * @package PressBook_Media
 */

/**
 * Register block patterns.
 */
class PressBook_Media_Block_Patterns implements PressBook\Serviceable {
	/**
	 * Register service features.
	 */
	public function register() {
		/**
		 * Register block pattern category.
		 */
		if ( function_exists( 'register_block_pattern_category' ) ) {
			register_block_pattern_category(
				'pressbook-media',
				array( 'label' => esc_html__( 'PressBook Media', 'pressbook-media' ) )
			);
		}

		/**
		 * Register block patterns.
		 */
		if ( function_exists( 'register_block_pattern' ) ) {
			$this->block_pattern_hero_bg_color_light();
			$this->block_pattern_three_column_content_buttons_bg_light();
			$this->block_pattern_two_column_media_text_button_square_bg_light();
		}
	}

	/**
	 * Block pattern: Hero Section (Background Color - White).
	 */
	public function block_pattern_hero_bg_color_light() {
		register_block_pattern(
			'pressbook/hero-bg-color-light',
			array(
				'title'         => esc_html__( 'Hero Section (Background Color - White)', 'pressbook-media' ),
				'categories'    => array( 'pressbook-media' ),
				'viewportWidth' => 1440,
				'content'       => '<!-- wp:group {"backgroundColor":"white","textColor":"black","className":"pressbook-hero-section pressbook-hero-bg-color"} --> <div class="wp-block-group pressbook-hero-section pressbook-hero-bg-color has-black-color has-white-background-color has-text-color has-background"><!-- wp:heading {"textAlign":"center","textColor":"black"} --> <h2 class="has-text-align-center has-black-color has-text-color">' . esc_html__( 'Unlock Your Creativity', 'pressbook-media' ) . '</h2> <!-- /wp:heading --> <!-- wp:paragraph {"align":"center"} --> <p class="has-text-align-center">' . esc_html__( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Donec odio. Quisque volutpat mattis eros. Nullam malesuada erat ut turpis. Suspendisse urna nibh, viverra non, semper suscipit, posuere a, pede.', 'pressbook-media' ) . '</p> <!-- /wp:paragraph --> <!-- wp:buttons {"contentJustification":"center"} --> <div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"textColor":"luminous-vivid-orange","className":"pressbook-hero-section__button is-style-outline"} --> <div class="wp-block-button pressbook-hero-section__button is-style-outline"><a class="wp-block-button__link has-luminous-vivid-orange-color has-text-color" href="#">' . esc_html__( 'More Info', 'pressbook-media' ) . '</a></div> <!-- /wp:button --> <!-- wp:button {"backgroundColor":"luminous-vivid-orange","textColor":"white","className":"pressbook-hero-section__button"} --> <div class="wp-block-button pressbook-hero-section__button"><a class="wp-block-button__link has-white-color has-luminous-vivid-orange-background-color has-text-color has-background" href="#">' . esc_html__( 'Read More', 'pressbook-media' ) . '</a></div> <!-- /wp:button --></div> <!-- /wp:buttons --></div> <!-- /wp:group -->',
			)
		);
	}

	/**
	 * Block pattern: 3-Column Content with Buttons (White).
	 */
	public function block_pattern_three_column_content_buttons_bg_light() {
		register_block_pattern(
			'pressbook/three-column-content-buttons-bg-light',
			array(
				'title'         => esc_html__( '3-Column Content with Buttons (White)', 'pressbook-media' ),
				'categories'    => array( 'pressbook-media' ),
				'viewportWidth' => 1440,
				'content'       => '<!-- wp:group {"backgroundColor":"white","textColor":"black","className":"pressbook-column-content"} --> <div class="wp-block-group pressbook-column-content has-black-color has-white-background-color has-text-color has-background"><!-- wp:columns --> <div class="wp-block-columns"><!-- wp:column --> <div class="wp-block-column"><!-- wp:heading {"level":3,"textColor":"black"} --> <h3 class="has-black-color has-text-color">' . esc_html__( 'Lorem Ipsum', 'pressbook-media' ) . '</h3> <!-- /wp:heading --> <!-- wp:paragraph --> <p>' . esc_html__( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Donec odio. Quisque volutpat mattis eros. Nullam malesuada erat ut turpis.', 'pressbook-media' ) . '</p> <!-- /wp:paragraph --> <!-- wp:buttons --> <div class="wp-block-buttons"><!-- wp:button {"backgroundColor":"luminous-vivid-orange","textColor":"white","className":"pressbook-column-content-button is-style-fill"} --> <div class="wp-block-button pressbook-column-content-button is-style-fill"><a class="wp-block-button__link has-white-color has-luminous-vivid-orange-background-color has-text-color has-background" href="#">' . esc_html__( 'Read More', 'pressbook-media' ) . '</a></div> <!-- /wp:button --></div> <!-- /wp:buttons --></div> <!-- /wp:column --> <!-- wp:column --> <div class="wp-block-column"><!-- wp:heading {"level":3,"textColor":"black"} --> <h3 class="has-black-color has-text-color">' . esc_html__( 'Vestibulum auctor', 'pressbook-media' ) . '</h3> <!-- /wp:heading --> <!-- wp:paragraph --> <p>' . esc_html__( 'Donec nec justo eget felis facilisis fermentum. Aliquam porttitor mauris sit amet orci. Aenean dignissim pellentesque felis.', 'pressbook-media' ) . '</p> <!-- /wp:paragraph --> <!-- wp:buttons --> <div class="wp-block-buttons"><!-- wp:button {"backgroundColor":"luminous-vivid-orange","textColor":"white","className":"pressbook-column-content-button"} --> <div class="wp-block-button pressbook-column-content-button"><a class="wp-block-button__link has-white-color has-luminous-vivid-orange-background-color has-text-color has-background" href="#">' . esc_html__( 'Read More', 'pressbook-media' ) . '</a></div> <!-- /wp:button --></div> <!-- /wp:buttons --></div> <!-- /wp:column --> <!-- wp:column --> <div class="wp-block-column"><!-- wp:heading {"level":3,"textColor":"black"} --> <h3 class="has-black-color has-text-color">' . esc_html__( 'Aliquam tincidunt', 'pressbook-media' ) . '</h3> <!-- /wp:heading --> <!-- wp:paragraph --> <p>' . esc_html__( 'Morbi in sem quis dui placerat ornare. Pellentesque odio nisi, euismod in, pharetra a, ultricies in, diam. Sed arcu. Cras consequat.', 'pressbook-media' ) . '</p> <!-- /wp:paragraph --> <!-- wp:buttons --> <div class="wp-block-buttons"><!-- wp:button {"backgroundColor":"luminous-vivid-orange","textColor":"white","className":"pressbook-column-content-button"} --> <div class="wp-block-button pressbook-column-content-button"><a class="wp-block-button__link has-white-color has-luminous-vivid-orange-background-color has-text-color has-background" href="#">' . esc_html__( 'Read More', 'pressbook-media' ) . '</a></div> <!-- /wp:button --></div> <!-- /wp:buttons --></div> <!-- /wp:column --></div> <!-- /wp:columns --></div> <!-- /wp:group -->',
			)
		);
	}

	/**
	 * Block pattern: 2-Column Media with Text and Button (Square White).
	 */
	public function block_pattern_two_column_media_text_button_square_bg_light() {
		register_block_pattern(
			'pressbook/two-column-media-text-button-square-bg-light',
			array(
				'title'         => esc_html__( '2-Column Media with Text and Button (Square White)', 'pressbook-media' ),
				'categories'    => array( 'pressbook-media' ),
				'viewportWidth' => 1440,
				'content'       => '<!-- wp:cover {"overlayColor":"white","minHeight":450,"minHeightUnit":"px","contentPosition":"center center","align":"wide","className":"pressbook-media-text-button pressbook-column-content"} --> <div class="wp-block-cover alignwide has-white-background-color has-background-dim pressbook-media-text-button pressbook-column-content" style="min-height:450px"><div class="wp-block-cover__inner-container"><!-- wp:columns {"verticalAlignment":null} --> <div class="wp-block-columns"><!-- wp:column {"verticalAlignment":"center","width":"50%"} --> <div class="wp-block-column is-vertically-aligned-center" style="flex-basis:50%"><!-- wp:image {"sizeSlug":"large","linkDestination":"none","className":"is-style-default"} --> <figure class="wp-block-image size-large is-style-default"><img src="' . esc_url( get_stylesheet_directory_uri() ) . '/assets/images/office-desk.jpg" alt="' . esc_attr__( 'Office Desk', 'pressbook-media' ) . '"/><figcaption><span style="color:#555555" class="has-inline-color">' . esc_html__( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit.', 'pressbook-media' ) . '</span></figcaption></figure> <!-- /wp:image --></div> <!-- /wp:column --> <!-- wp:column {"verticalAlignment":"center","width":"50%"} --> <div class="wp-block-column is-vertically-aligned-center" style="flex-basis:50%"><!-- wp:heading {"className":"no-t-margin","style":{"color":{"text":"#404040"}}} --> <h2 class="no-t-margin has-text-color" style="color:#404040">' . esc_html__( 'Praesent dapibus', 'pressbook-media' ) . '</h2> <!-- /wp:heading --> <!-- wp:paragraph {"style":{"color":{"text":"#404040"}}} --> <p class="has-text-color" style="color:#404040">' . esc_html__( 'Praesent dapibus, neque id cursus faucibus, tortor neque egestas augue, eu vulputate magna eros eu erat. Aliquam erat volutpat. Nam dui mi, tincidunt quis, accumsan porttitor, facilisis luctus, metus.', 'pressbook-media' ) . '</p> <!-- /wp:paragraph --> <!-- wp:buttons --> <div class="wp-block-buttons"><!-- wp:button {"borderRadius":0,"backgroundColor":"vivid-red","textColor":"white","className":"pressbook-column-content-button is-style-fill"} --> <div class="wp-block-button pressbook-column-content-button is-style-fill"><a class="wp-block-button__link has-white-color has-vivid-red-background-color has-text-color has-background no-border-radius" href="#">' . esc_html__( 'Read More', 'pressbook-media' ) . '</a></div> <!-- /wp:button --></div> <!-- /wp:buttons --></div> <!-- /wp:column --></div> <!-- /wp:columns --></div></div> <!-- /wp:cover -->',
			)
		);
	}
}
